@@ -196,6 +196,45 @@
  *	g_object_unref (feed);
  * 	</programlisting>
  * </example>
+ *
+ * <example>
+ * 	<title>Querying for Videos using Search Terms</title>
+ * 	<programlisting>
+ *	GDataYouTubeService *service;
+ *	GDataYouTubeQuery *query;
+ *	GDataFeed *feed;
+ *	GList *i;
+ *	GError *error = NULL;
+ *
+ *	/<!-- -->* Create a service *<!-- -->/
+ *	service = create_youtube_service ();
+ *
+ *	/<!-- -->* Build a query with the given search terms, also matching only videos which are CC-licensed *<!-- -->/
+ *	query = gdata_youtube_query_new (my_space_separated_search_terms);
+ *	gdata_youtube_query_set_license (query, GDATA_YOUTUBE_LICENSE_CC);
+ *
+ *	/<!-- -->* Query for the videos matching the query parameters *<!-- -->/
+ *	feed = gdata_youtube_service_query_videos (service, query, NULL, NULL, NULL, &error);
+ *
+ *	g_object_unref (query);
+ *	g_object_unref (service);
+ *
+ *	if (error != NULL) {
+ *		g_error ("Error querying for videos matching search terms ‘%s’: %s", my_space_separated_search_terms, error->message);
+ *		g_error_free (error);
+ *		return;
+ *	}
+ *
+ *	/<!-- -->* Iterate through the videos *<!-- -->/
+ *	for (i = gdata_feed_get_entries (feed); i != NULL; i = i->next) {
+ *		GDataYouTubeVideo *video = GDATA_YOUTUBE_VIDEO (i->data);
+ *
+ *		/<!-- -->* Do something with the video, like insert it into the UI *<!-- -->/
+ *	}
+ *
+ *	g_object_unref (feed);
+ * 	</programlisting>
+ * </example>
  **/
 
 #include <config.h>
@@ -951,6 +990,7 @@ get_categories_thread (GSimpleAsyncResult *result, GDataYouTubeService *service,
 	if (error != NULL) {
 		g_simple_async_result_set_from_error (result, error);
 		g_error_free (error);
+		return;
 	}
 
 	g_simple_async_result_set_op_res_gpointer (result, categories, (GDestroyNotify) g_object_unref);
