@@ -38,9 +38,6 @@ gdata_test_init (int argc, char **argv)
 	gint i;
 
 	g_type_init ();
-#if !GLIB_CHECK_VERSION (2, 31, 0)
-	g_thread_init (NULL);
-#endif
 
 	/* Parse the --no-internet and --no-interactive options */
 	for (i = 1; i < argc; i++) {
@@ -541,15 +538,11 @@ compare_xml_nodes (xmlNode *node1, xmlNode *node2)
 }
 
 gboolean
-gdata_test_compare_xml (GDataParsable *parsable, const gchar *expected_xml, gboolean print_error)
+gdata_test_compare_xml_strings (const gchar *parsable_xml, const gchar *expected_xml, gboolean print_error)
 {
 	gboolean success;
-	gchar *parsable_xml;
 	xmlDoc *parsable_doc, *expected_doc;
 
-	/* Get an XML string for the GDataParsable */
-	parsable_xml = gdata_parsable_get_xml (parsable);
-
 	/* Parse both the XML strings */
 	parsable_doc = xmlReadMemory (parsable_xml, strlen (parsable_xml), "/dev/null", NULL, 0);
 	expected_doc = xmlReadMemory (expected_xml, strlen (expected_xml), "/dev/null", NULL, 0);
@@ -565,11 +558,44 @@ gdata_test_compare_xml (GDataParsable *parsable, const gchar *expected_xml, gboo
 
 	xmlFreeDoc (expected_doc);
 	xmlFreeDoc (parsable_doc);
+
+	return success;
+}
+
+gboolean
+gdata_test_compare_xml (GDataParsable *parsable, const gchar *expected_xml, gboolean print_error)
+{
+	gboolean success;
+	gchar *parsable_xml;
+
+	/* Get an XML string for the GDataParsable */
+	parsable_xml = gdata_parsable_get_xml (parsable);
+	success = gdata_test_compare_xml_strings (parsable_xml, expected_xml, print_error);
 	g_free (parsable_xml);
 
 	return success;
 }
 
+gboolean
+gdata_test_compare_kind (GDataEntry *entry, const gchar *expected_term, const gchar *expected_label)
+{
+	GList *list;
+
+	/* Check the entry's kind category is present and correct */
+	for (list = gdata_entry_get_categories (entry); list != NULL; list = list->next) {
+		GDataCategory *category = GDATA_CATEGORY (list->data);
+
+		if (g_strcmp0 (gdata_category_get_scheme (category), "http://schemas.google.com/g/2005#kind") == 0) {
+			/* Found the kind category; check its term and label. */
+			return (g_strcmp0 (gdata_category_get_term (category), expected_term) == 0) &&
+			       (g_strcmp0 (gdata_category_get_label (category), expected_label) == 0);
+		}
+	}
+
+	/* No kind! */
+	return FALSE;
+}
+
 /* Common code for tests of async query functions that have progress callbacks */
 
 void
